@@ -51,7 +51,7 @@ app = Flask(__name__)
 
 @app.route('/')
 def hello():
-  return 'Hello World'
+  return render_template('index.html')
 
 if __name__ == '__main__':
   app.run()
